@@ -2,4 +2,4 @@ from __future__ import unicode_literals, print_function, absolute_import
 
 from .filter import Filter
 
-__all__ = [ 'Filter' ]
+__all__ = ["Filter"]
